@@ -54,13 +54,27 @@ class Plugin:
             default=False,
             help='Prevent flagging of annotations for class definitions.',
         )
+        option_manager.add_option(
+            '--type-checking-pydantic-enabled-baseclass-passlist',
+            comma_separated_list=True,
+            parse_from_config=True,
+            default=[],
+            help='Names of base classes to not treat as pydantic models. For example `NamedTuple` or `TypedDict`.',
+        )
         option_manager.add_option(
             '--type-checking-fastapi-enabled',
             action='store_true',
             parse_from_config=True,
-            default=True,
+            default=False,
             help='Prevent flagging of annotations for decorated functions.',
         )
+        option_manager.add_option(
+            '--type-checking-fastapi-dependency-support-enabled',
+            action='store_true',
+            parse_from_config=True,
+            default=False,
+            help='Prevent flagging of annotations for any function.',
+        )
 
     def run(self) -> Flake8Generator:
         """Run flake8 plugin and return any relevant errors."""
